@@ -807,42 +807,37 @@ func ValidateNodeGroup(i int, ng *NodeGroup, cfg *ClusterConfig) error {
 		}
 	}
 
-	if IsWindowsImage(ng.AMIFamily) || ng.AMIFamily == NodeImageFamilyBottlerocket {
-		fieldNotSupported := func(field string) error {
-			return &unsupportedFieldError{
-				ng:    ng.NodeGroupBase,
-				path:  path,
-				field: field,
-			}
+	fieldNotSupported := func(field string) error {
+		return &unsupportedFieldError{
+			ng:    ng.NodeGroupBase,
+			path:  path,
+			field: field,
 		}
+	}
 
+	if IsWindowsImage(ng.AMIFamily) {
 		if ng.KubeletExtraConfig != nil {
 			return fieldNotSupported("kubeletExtraConfig")
 		}
-
-		if IsWindowsImage(ng.AMIFamily) && ng.OverrideBootstrapCommand != nil {
+	} else if ng.AMIFamily == NodeImageFamilyBottlerocket {
+		if ng.KubeletExtraConfig != nil {
+			return fieldNotSupported("kubeletExtraConfig")
+		}
+		if ng.PreBootstrapCommands != nil {
+			return fieldNotSupported("preBootstrapCommands")
+		}
+		if ng.OverrideBootstrapCommand != nil {
 			return fieldNotSupported("overrideBootstrapCommand")
 		}
-
-		if ng.AMIFamily == NodeImageFamilyBottlerocket {
-			if ng.PreBootstrapCommands != nil {
-				return fieldNotSupported("preBootstrapCommands")
-			}
-			if ng.OverrideBootstrapCommand != nil {
-				return fieldNotSupported("overrideBootstrapCommand")
+		if ng.Bottlerocket != nil {
+			if err := checkBottlerocketSettings(ng.Bottlerocket.Settings, path); err != nil {
+				return err
 			}
 		}
 	} else if err := validateNodeGroupKubeletExtraConfig(ng.KubeletExtraConfig); err != nil {
 		return err
 	}
 
-	if ng.AMIFamily == NodeImageFamilyBottlerocket && ng.Bottlerocket != nil {
-		err := checkBottlerocketSettings(ng.Bottlerocket.Settings, path)
-		if err != nil {
-			return err
-		}
-	}
-
 	if instanceutils.IsARMGPUInstanceType(SelectInstanceType(ng)) && ng.AMIFamily != NodeImageFamilyBottlerocket {
 		return fmt.Errorf("ARM GPU instance types are not supported for unmanaged nodegroups with AMIFamily %s", ng.AMIFamily)
 	}
@@ -1212,8 +1207,8 @@ func ValidateManagedNodeGroup(index int, ng *ManagedNodeGroup) error {
 		if ng.AMIFamily == "" {
 			return errors.Errorf("when using a custom AMI, amiFamily needs to be explicitly set via config file or via --node-ami-family flag")
 		}
-		if ng.AMIFamily != NodeImageFamilyAmazonLinux2 {
-			return errors.Errorf("cannot set amiFamily to %s when using a custom AMI for managed nodes, only %s is supported", ng.AMIFamily, NodeImageFamilyAmazonLinux2)
+		if ng.AMIFamily != NodeImageFamilyAmazonLinux2 && ng.AMIFamily != NodeImageFamilyUbuntu1804 && ng.AMIFamily != NodeImageFamilyUbuntu2004 {
+			return errors.Errorf("cannot set amiFamily to %s when using a custom AMI for managed nodes, only %s, %s and %s are supported", ng.AMIFamily, NodeImageFamilyAmazonLinux2, NodeImageFamilyUbuntu1804, NodeImageFamilyUbuntu2004)
 		}
 		if ng.OverrideBootstrapCommand == nil {
 			return errors.Errorf("%s.overrideBootstrapCommand is required when using a custom AMI (%s.ami)", path, path)
